========
SageMath
========
----------------------------------------------
A free open-source mathematics software system
----------------------------------------------

This is a dummy package that checks that Sage is installed in the system. Please see www.sagemath.org for instructions on how to download and install the actual software.

SageMath is a free open-source mathematics software system licensed under the GPL. It builds on top of many existing open-source packages: NumPy, SciPy, matplotlib, Sympy, Maxima, GAP, FLINT, R and many more. Access their combined power through a common, Python-based language or directly via interfaces or wrappers.


